==> knutclient_0.9.3.orig.tar.gz: knutclient-0.9.3/src/knutconst.h <==
/***************************************************************************
                          knutconst.h  -  description
                             -------------------
    begin                : Tue Sep 24 2001
    copyright            : (C) 2003 by Daniel Prynych
    email                : Daniel.Prynych@alo.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNUTCONST_H
#define KNUTCONST_H


namespace knc {

  const int StartPort =1024;
  const int StopPort= 65535;
  const int MinDelay = 2000;

  const int MinCols = 1;
  const int MaxCols = 5;

  const int DefaultCountCols = 3; // prednastaveny pocet sloupcu analogovych meraku
  const int DefaultPort = 3493;  // default ports - prednastaveny port

  const int DefaultDelay = 2000; //2000 msec

  const int DefaultInputVoltage = 230;
  const int DefaultInputFrequency = 50;

  const int NumberOfVars = 10; // how many variables we can measure //  kolik promenych muzeme merit 
  const int NumberOfTypes = 13; // pocet typu promenych (none,utility ....)

  enum {VarNone,VarUtility,VarBattPct,VarUpsTemp,VarAcfreq,VarLoadPct,VarAmbTemp,VarAmbHumid,VarBattVolt,VarOutVolt,VarCurrent,VarBattTemp,VarBattCurrent};

  const unsigned int maxCountKNutEvent = 100;

  const int numberVarError = -1000;

  enum upsDriverConnection {  // state of connection to usbd, this isn't state of knutnet 
    connecting,
    connected,
    stale,
    notConnected,
    error
    };
  }


#endif

==> knutclient_0.9.4.orig.tar.gz: knutclient-0.9.4.orig/src/knutconst.h <==
/***************************************************************************
                          knutconst.h  -  description
                             -------------------
    begin                : Tue Sep 24 2001
    copyright            : (C) 2003 by Daniel Prynych
    email                : Daniel.Prynych@alo.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNUTCONST_H
#define KNUTCONST_H


namespace knc {

  const int StartPort =1024;
  const int StopPort= 65535;
  const int MinDelay = 2000;

  const int MinCols = 1;
  const int MaxCols = 5;

  const int DefaultCountCols = 3; // prednastaveny pocet sloupcu analogovych meraku
  const int DefaultPort = 3493;  // default ports - prednastaveny port

  const int DefaultDelay = 2000; //2000 msec

  const int DefaultInputVoltage = 230;
  const int DefaultInputFrequency = 50;

  const int NumberOfVars = 10; // how many variables we can measure //  kolik promenych muzeme merit 
  const int NumberOfTypes = 14; // count types of variables //  pocet typu promenych (none,utility ....)

  enum {VarNone,VarUtility,VarBattPct,VarUpsTemp,VarAcfreq,VarLoadPct,VarAmbTemp,VarAmbHumid,VarBattVolt,VarOutVolt,VarCurrent,VarOutFreq,VarBattTemp,VarBattCurrent};

  const unsigned int maxCountKNutEvent = 100;

  const int numberVarError = -1000;

  enum upsDriverConnection {  // state of connection to usbd, this isn't state of knutnet 
    connecting,
    connected,
    stale,
    notConnected,
    error
    };
  }


#endif
